# Generated by Django 3.2.13 on 2022-07-11 10:30

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_microbiology", "0008_auto_20220224_1926"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="historicalmicrobiology",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Microbiology",
                "verbose_name_plural": "historical Microbiology",
            },
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
    ]
